pub struct Cell {
pub text: CellText,
pub style: Style,
}Expand description
A single cell on the buffer with text and style.
Fields
text: CellTextThe text.
This is a string because certain combinations of unicode characters may still fit in a cell.
style: StyleThe style of the cell